SlickGrid example: Grouping

SlickGrid
Options:

Show tasks with % at least:

## Demonstrates:

- Fully dynamic and interactive multi-level grouping with filtering and aggregates over 50'000 items
  Each grouping level can have its own aggregates (over child rows, child groups, or all descendant rows).
  Personally, this is just the coolest slickest thing I've ever seen done with DHTML grids!

## View Source:

- View the source for this example on Github